@@ -1,8 +1,26 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
+#
+# Copyright 2021 The NiPreps Developers <nipreps@gmail.com>
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+# We support and encourage derived works from this project, please read
+# about our expectations at
+#
+#     https://www.nipreps.org/community/licensing/
+#
 """Miscellaneous utilities."""
-import os
-import shutil
 
 
 __all__ = [
@@ -253,17 +271,17 @@ def clean_directory(path):
     This function is not guaranteed to work across multiple threads or processes.
 
     """
-    for f in os.scandir(path):  # switch to context manager when py35 dropped
-        if f.is_file() or f.is_symlink():
-            try:
-                os.unlink(f.path)
-            except OSError:
-                return False
-        elif f.is_dir():
-            try:
-                shutil.rmtree(f.path)
-            except OSError:
-                return False
+    from pathlib import Path
+    import shutil
+
+    try:
+        for f in Path(path).iterdir():
+            if f.is_file() or f.is_symlink():
+                f.unlink()
+            elif f.is_dir():
+                shutil.rmtree(str(f))
+    except OSError:
+        return False
     return True
 
 
@@ -289,7 +307,7 @@ def pass_dummy_scans(algo_dummy_scans, dummy_scans=None):
     return dummy_scans
 
 
-def check_valid_fs_license(lic=None):
+def check_valid_fs_license():
     """
     Run ``mri_convert`` to assess FreeSurfer access to a license.
 
@@ -304,13 +322,6 @@ def check_valid_fs_license(lic=None):
     from tempfile import TemporaryDirectory
     from pkg_resources import resource_filename
 
-    if lic is not None:
-        import warnings
-        warnings.warn("The license argument has been deprecated, has no effect, and will be "
-                      "removed in 1.3.0. Please set the environment if needed before calling "
-                      "this function without arguments.",
-                      DeprecationWarning)
-
     with TemporaryDirectory() as tmpdir:
         # quick FreeSurfer command
         _cmd = (
